Package: grainscape
Type: Package
Title: Landscape Connectivity, Habitat, and Protected Area Networks
Description: Given a landscape resistance surface, creates minimum planar graph
    (Fall et al. (2007) <doi:10.1007/s10021-007-9038-7>) and grains of connectivity
    (Galpern et al. (2012) <doi:10.1111/j.1365-294X.2012.05677.x>) models that can be
    used to calculate effective distances for landscape connectivity at multiple scales.
    Documentation is provided by several vignettes, and a paper
    (Chubaty, Galpern & Doctolero (2020) <doi:10.1111/2041-210X.13350>).
URL: https://www.alexchubaty.com/grainscape/,
        https://github.com/achubaty/grainscape
Version: 0.5.0
Date: 2025-01-14
Authors@R: c(
    person("Paul", "Galpern", email = "pgalpern@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-0099-3981")),
    person("Sam", "Doctolero", email = "sam.doctolero@gmail.com", role = "aut"),
    person("Alex M", "Chubaty", email = "achubaty@for-cast.ca", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-7146-8135"))
    )
License: GPL (>= 2)
Depends: R (>= 4.2)
Imports: ggplot2, graphics, grDevices, igraph, methods, raster, Rcpp
        (>= 0.12.11.4), sf, sp, stats, utils
LinkingTo: Rcpp
Suggests: covr, cowplot, DiagrammeR, dplyr, ggthemes, knitr, parallel,
        rmarkdown, spelling, testthat, webshot2, withr
VignetteBuilder: knitr, rmarkdown
BugReports: https://github.com/achubaty/grainscape/issues
ByteCompile: yes
Collate: 'grainscape-package.R' 'classes.R' 'GOC.R' 'MPG.R'
        'RcppExports.R' 'grain.R' 'corridor.R' 'distance.R' 'export.R'
        'extract.R' 'ggGS.R' 'grainscape-deprecated.R' 'graphdf.R'
        'habitatConnectivityEngine.R' 'patchFilter.R' 'plot.R'
        'point.R' 'theme_grainscape.R' 'threshold.R' 'zzz.R'
Encoding: UTF-8
Language: en-CA
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-01-15 03:54:04 UTC; achubaty
Author: Paul Galpern [aut, cph] (<https://orcid.org/0000-0003-0099-3981>),
  Sam Doctolero [aut],
  Alex M Chubaty [aut, cre] (<https://orcid.org/0000-0001-7146-8135>)
Maintainer: Alex M Chubaty <achubaty@for-cast.ca>
Repository: CRAN
Date/Publication: 2025-01-15 08:00:06 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 07:54:10 UTC; unix
Archs: grainscape.so.dSYM
