# Generated by roxygen2: do not edit by hand

export(GOC)
export(MPG)
export(corridor)
export(distance)
export(export)
export(ggGS)
export(grain)
export(graphdf)
export(gsGOC)
export(gsGOCCorridor)
export(gsGOCDistance)
export(gsGOCPoint)
export(gsGOCVisualize)
export(gsGraphDataFrame)
export(gsMPG)
export(gsMPGstitch)
export(patchFilter)
export(point)
export(theme_grainscape)
export(threshold)
exportMethods("$")
exportMethods("$<-")
exportMethods(GOC)
exportMethods(MPG)
exportMethods(corridor)
exportMethods(distance)
exportMethods(export)
exportMethods(ggGS)
exportMethods(grain)
exportMethods(graphdf)
exportMethods(patchFilter)
exportMethods(plot)
exportMethods(point)
exportMethods(show)
exportMethods(threshold)
import(igraph)
import(methods)
importClassesFrom(raster,RasterLayer)
importClassesFrom(sp,SpatialLines)
importClassesFrom(sp,SpatialLinesDataFrame)
importClassesFrom(sp,SpatialPoints)
importClassesFrom(sp,SpatialPolygons)
importClassesFrom(sp,SpatialPolygonsDataFrame)
importFrom(Rcpp,evalCpp)
importFrom(ggplot2,"%+replace%")
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_equal)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_raster)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,scale_colour_identity)
importFrom(ggplot2,scale_fill_identity)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_size_identity)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(grDevices,rainbow)
importFrom(graphics,plot)
importFrom(raster,"extension<-")
importFrom(raster,"projection<-")
importFrom(raster,as.data.frame)
importFrom(raster,boundaries)
importFrom(raster,cellFromRowCol)
importFrom(raster,cellFromRowColCombine)
importFrom(raster,cellFromXY)
importFrom(raster,clump)
importFrom(raster,compareRaster)
importFrom(raster,extent)
importFrom(raster,freq)
importFrom(raster,getValues)
importFrom(raster,mask)
importFrom(raster,ncol)
importFrom(raster,nrow)
importFrom(raster,plot)
importFrom(raster,projection)
importFrom(raster,raster)
importFrom(raster,rasterToPolygons)
importFrom(raster,reclassify)
importFrom(raster,res)
importFrom(raster,unique)
importFrom(raster,writeRaster)
importFrom(raster,xFromCol)
importFrom(raster,xmax)
importFrom(raster,xmin)
importFrom(raster,xyFromCell)
importFrom(raster,yFromRow)
importFrom(raster,ymax)
importFrom(raster,ymin)
importFrom(raster,zonal)
importFrom(sf,st_as_sf)
importFrom(sf,st_write)
importFrom(sp,"coordinates<-")
importFrom(sp,"proj4string<-")
importFrom(sp,CRS)
importFrom(sp,Line)
importFrom(sp,Lines)
importFrom(sp,SpatialLines)
importFrom(sp,SpatialLinesDataFrame)
importFrom(sp,SpatialPixelsDataFrame)
importFrom(sp,SpatialPoints)
importFrom(sp,SpatialPolygonsDataFrame)
importFrom(sp,coordinates)
importFrom(sp,geometry)
importFrom(sp,plot)
importFrom(sp,proj4string)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(utils,read.table)
importFrom(utils,type.convert)
useDynLib(grainscape, .registration = TRUE)
